@@ -124,6 +124,7 @@ static void reuse_CachedSession(const iCachedSession *d, SSL *ssl) {
 }
 
 struct Impl_Context {
+    iString               libraryName;
     SSL_CTX *             ctx;
     X509_STORE *          certStore;
     iTlsRequestVerifyFunc userVerifyFunc;
@@ -230,6 +231,12 @@ static int verifyCallback_Context_(int preverifyOk, X509_STORE_CTX *storeCtx) {
 }
 
 void init_Context(iContext *d) {
+    init_String(&d->libraryName);
+#if defined (LIBRESSL_VERSION_TEXT)
+    setCStr_String(&d->libraryName, "LibreSSL");
+#else
+    setCStr_String(&d->libraryName, "OpenSSL");
+#endif
     d->tssKeyCurrentRequest = 0;
     tss_create(&d->tssKeyCurrentRequest, NULL);
 #if OPENSSL_API_COMPAT >= 0x10100000L
@@ -263,6 +270,7 @@ void deinit_Context(iContext *d) {
     deinit_Mutex(&d->cacheMutex);
     SSL_CTX_free(d->ctx);
     tss_delete(d->tssKeyCurrentRequest);
+    deinit_String(&d->libraryName);
 }
 
 iBool isValid_Context(iContext *d) {
@@ -318,6 +326,7 @@ struct Impl_TlsCertificate {
 iDefineTypeConstruction(TlsCertificate)
 
 void init_TlsCertificate(iTlsCertificate *d) {
+    initContext_();
     d->cert  = NULL;
     d->chain = NULL;
     d->pkey  = NULL;
@@ -424,6 +433,7 @@ static void checkErrors_(void) {
 
 iTlsCertificate *newSelfSignedRSA_TlsCertificate(
     int rsaBits, iDate validUntil, const iTlsCertificateName *names) {
+    initContext_();
     /* Seed the random number generator. */
     if (!isPrngSeeded_) {
         iTime now;
@@ -826,6 +836,11 @@ void setCiphers_TlsRequest(const char *cipherList) {
     SSL_CTX_set_cipher_list(context_->ctx, cipherList);
 }
 
+const char *libraryName_TlsRequest(void) {
+    initContext_();
+    return cstr_String(&context_->libraryName);
+}
+
 void init_TlsRequest(iTlsRequest *d) {
     initContext_();
     init_Mutex(&d->mtx);
